using SkyMaps
import SkyMaps as SM
using Tables
using AstroIceCube
using AstroANTARES
using Test


@testset "healpix" begin
    hm = skymap_healpix(dataset(IceCube.Map7yr()))
    @test length(rowtable(hm)) == 3145728
    @test rowtable(hm)[1234].coords ≈ [2.10487, 1.53093]  rtol=1e-5
    @test rowtable(hm)[1234].value ≈ 0.00568758  rtol=1e-5
    @test SM.ix_to_coords(hm, 1234) ≈ [2.10487, 1.53093]  rtol=1e-5
    @test SM.find_closest(hm, SM.ix_to_coords(hm, 1234)) == 1234
    @test SM.find_closest(hm, deg2rad.((-10, 80))) == 24408
    @test hm(deg2rad.((-10, 80))) == 0.004934858530759811
    @test hm(rowtable(hm)[1234].coords) == rowtable(hm)[1234].value
end

@testset "root" begin
    rsm = skymap_root(dataset(ANTARES.MapPrivate()))
    @test length(rowtable(rsm)) == 1620000
    @test rowtable(rsm)[123456].coords ≈ [3.68439, -1.33169]  rtol=1e-5
    @test rowtable(rsm)[123456].value ≈ 0.400076  rtol=1e-5
    @test SM.find_closest(rsm, SM.ix_to_coords(rsm, CartesianIndex(123, 456))) == CartesianIndex(123, 456)
    @test SM.ix_to_coords(rsm, SM.find_closest(rsm, deg2rad.((-10, 80)))) .|> rad2deg ≈ [350.1, 80.1]
    @test SM.find_closest(rsm, deg2rad.((-10, 80))) == CartesianIndex(1751, 851)
    @test rsm(deg2rad.((-10, 20))) == 0.1260606324106659
    @test rsm(rowtable(rsm)[123456].coords) == rowtable(rsm)[123456].value
end


import CompatHelperLocal as CHL
CHL.@check()
